@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2011-2021 by Ilya Kotov                                 *
+ *   Copyright (C) 2011-2025 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -81,7 +81,7 @@ bool DecoderFFap::initialize()
     if(ffap_init(m_ffap_decoder) == -1)
     {
         deinit();
-        qWarning("DecoderFFap: unable to initialize decoder");
+        qCWarning(plugin) << "unable to initialize decoder";
         return false;
     }
     Qmmp::AudioFormat format = Qmmp::PCM_UNKNOWN;
@@ -104,7 +104,7 @@ bool DecoderFFap::initialize()
         return false;
     }
     configure(m_ffap_decoder->samplerate, m_ffap_decoder->channels, format);
-    qDebug("DecoderFFap: initialize succes");
+    qCDebug(plugin) << "initialize succes";
     return true;
 }
 
