@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2011-2021 by Ilya Kotov                                 *
+ *   Copyright (C) 2011-2025 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -18,23 +18,20 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
-#include <QTextCodec>
 #include <QRegularExpression>
 #include <taglib/tag.h>
 #include <taglib/id3v1tag.h>
 #include <taglib/apetag.h>
 #include <qmmp/metadatamanager.h>
+#include <qmmp/qmmptextcodec.h>
 #include "ffapmetadatamodel.h"
 
 FFapMetaDataModel::FFapMetaDataModel(const QString &path, bool readOnly) : MetaDataModel(true)
 {
-    if(path.contains("://"))
+    if(path.contains(u"://"_s))
     {
-        QString p = path;
-        p.remove("ape://");
-        p.remove(QRegularExpression("#\\d+$"));
-        m_path = p;
-        m_stream = new TagLib::FileStream(QStringToFileName(p), true);
+        m_path = TrackInfo::pathFromUrl(path);
+        m_stream = new TagLib::FileStream(QStringToFileName(m_path), true);
         m_file = new TagLib::APE::File(m_stream);
     }
     else
@@ -85,23 +82,25 @@ FFapFileTagModel::FFapFileTagModel(TagLib::APE::File *file, TagLib::APE::File::T
     if (m_tagType == TagLib::APE::File::ID3v1)
     {
         m_tag = m_file->ID3v1Tag();
-        m_codec = QTextCodec::codecForName("ISO-8859-1");
+        m_codec = new QmmpTextCodec("ISO-8859-1");
     }
     else
     {
         m_tag = m_file->APETag();
-        m_codec = QTextCodec::codecForName ("UTF-8");
+        m_codec = new QmmpTextCodec("UTF-8");
     }
 }
 
 FFapFileTagModel::~FFapFileTagModel()
-{}
+{
+    delete m_codec;
+}
 
 QString FFapFileTagModel::name() const
 {
     if (m_tagType == TagLib::APE::File::ID3v1)
-        return "ID3v1";
-    return "APE";
+        return u"ID3v1"_s;
+    return u"APE"_s;
 }
 
 QList<Qmmp::MetaData> FFapFileTagModel::keys() const
