@@ -6,50 +6,50 @@
     <message>
         <location filename="../ytbinputfactory.cpp" line="36"/>
         <source>Youtube Plugin</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../ytbinputfactory.cpp" line="69"/>
-        <source>About Youtube Transport Plugin</source>
-        <translation type="unfinished"></translation>
+        <translation>Youtube 插件</translation>
     </message>
     <message>
         <location filename="../ytbinputfactory.cpp" line="70"/>
-        <source>Qmmp Youtube Transport Plugin</source>
-        <translation type="unfinished"></translation>
+        <source>About Youtube Transport Plugin</source>
+        <translation>關於Youtube傳輸插件</translation>
     </message>
     <message>
         <location filename="../ytbinputfactory.cpp" line="71"/>
-        <source>This plugin adds feature to play audio from Youtube using %1 utility</source>
-        <translation type="unfinished"></translation>
+        <source>Qmmp Youtube Transport Plugin</source>
+        <translation>Qmmp Youtube傳輸插件</translation>
     </message>
     <message>
-        <location filename="../ytbinputfactory.cpp" line="73"/>
-        <source>%1 version: %2</source>
-        <translation type="unfinished"></translation>
+        <location filename="../ytbinputfactory.cpp" line="72"/>
+        <source>This plugin adds feature to play audio from Youtube using %1 utility</source>
+        <translation>這個插件增加了使用 %1  工具從 YouTube 播放音訊的功能。</translation>
     </message>
     <message>
         <location filename="../ytbinputfactory.cpp" line="74"/>
+        <source>%1 version: %2</source>
+        <translation>%1 版本： %2</translation>
+    </message>
+    <message>
+        <location filename="../ytbinputfactory.cpp" line="75"/>
         <source>Written by: Ilya Kotov &amp;lt;forkotov02@ya.ru&amp;gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>撰寫： Ilya Kotov &amp;lt;forkotov02@ya.ru&amp;gt;</translation>
     </message>
 </context>
 <context>
     <name>YtbInputSource</name>
-    <message>
-        <location filename="../ytbinputsource.cpp" line="184"/>
-        <source>Uploader</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../ytbinputsource.cpp" line="185"/>
-        <source>Upload date</source>
-        <translation type="unfinished"></translation>
+        <source>Uploader</source>
+        <translation>上傳器</translation>
     </message>
     <message>
         <location filename="../ytbinputsource.cpp" line="186"/>
+        <source>Upload date</source>
+        <translation>上傳日期</translation>
+    </message>
+    <message>
+        <location filename="../ytbinputsource.cpp" line="187"/>
         <source>Duration</source>
-        <translation type="unfinished"></translation>
+        <translation>持續時間</translation>
     </message>
 </context>
 </TS>
