@@ -34,12 +34,14 @@
         <translation>&amp;Başlığı Göster</translation>
     </message>
     <message>
-        <location filename="../goomwidget.cpp" line="201"/>
+        <location filename="../goomwidget.cpp" line="202"/>
+        <location filename="../goomwidget.cpp" line="204"/>
         <source>&amp;Full Screen</source>
         <translation>&amp;Tam Ekran</translation>
     </message>
     <message>
-        <location filename="../goomwidget.cpp" line="201"/>
+        <location filename="../goomwidget.cpp" line="202"/>
+        <location filename="../goomwidget.cpp" line="204"/>
         <source>F</source>
         <translation>F</translation>
     </message>
@@ -79,7 +81,7 @@
     <message>
         <location filename="../visualgoomfactory.cpp" line="54"/>
         <source>Jean-Christophe Hoelt &lt;jeko@ios-software.com&gt;</source>
-        <translation>Jean-Christophe Hoelt &lt;jeko@ios-software.com&gt; </translation>
+        <translation>Jean-Christophe Hoelt &lt;jeko@ios-software.com&gt;&#xa0;</translation>
     </message>
     <message>
         <location filename="../visualgoomfactory.cpp" line="55"/>
